@@ -24,9 +24,9 @@
 #define CT_STRINGIFY(x)		#x
 #define CT_STR(x)		CT_STRINGIFY(x)
 
-#define CT_VERSION_MAJOR	1
-#define CT_VERSION_MINOR	6
-#define CT_VERSION_PATCH	2
+#define CT_VERSION_MAJOR	2
+#define CT_VERSION_MINOR	0
+#define CT_VERSION_PATCH	0
 #define CT_VERSION		CT_STR(CT_VERSION_MAJOR) "." \
 				CT_STR(CT_VERSION_MINOR) "." \
 				CT_STR(CT_VERSION_PATCH)
@@ -57,6 +57,10 @@ struct ct_config {
 	long long	ct_ctfile_max_cachesize;
 	int	ct_secrets_upload;
 	int	ct_io_bw_limit;
+#define CT_DEFAULT_RCVBUF	(64*1024)
+	int	ct_sock_rcvbuf;
+#define CT_DEFAULT_SNDBUF	(64*1024)
+	int	ct_sock_sndbuf;
 };
 
 int			 ct_load_config(struct ct_config **, char **);
@@ -83,6 +87,7 @@ struct ct_statistics {
 
 	uint64_t		st_bytes_read;
 	uint64_t		st_bytes_written;
+	uint64_t		st_bytes_skipped;
 	uint64_t		st_bytes_compressed;
 	uint64_t		st_bytes_uncompressed;
 	uint64_t		st_bytes_crypted;
@@ -633,4 +638,9 @@ int			 ct_handle_unsolicited_xml(struct ct_header *, void *,
 #define CT_NO_OPENAT
 #endif
 
+/* Mac OS X doesn't have openat() */
+#if defined(__APPLE__)
+#define CT_NO_OPENAT
+#endif
+
 #endif /* ! CT_LIB_H */
